###################################
Release notes & upgrade information
###################################


The `CHANGELOG <https://github.com/aldryn/aldryn-categories/blob/master/CHANGELOG.rst>`_
is maintained and updated within the repository.
